Code section parsing.
Decodes function body records from the code section. Instruction sequences remain raw byte slices until instruction decoding is implemented. See Spec 5.5.13.
Code section parsing.
Decodes function body records from the code section. Instruction sequences remain raw byte slices until instruction decoding is implemented. See Spec 5.5.13.