Module module

Module module 

Top-level WASM module decoding.

Produces a Module — a parsed but not yet validated representation of a WASM binary. At this phase, section contents are stored as raw byte spans. Future phases will add full section content parsing.

See Spec 5.5.1.

Structs

Module
A parsed WASM module. Contains the raw section data segmented by type.